@@ -4,13 +4,14 @@ import json
 import logging
 from typing import Union
 
+from fastapi import Request
 from fastapi.responses import JSONResponse
 
-from .conbus import router
-from .errors import handle_service_error
-from ..models.api import ApiResponse, ApiErrorResponse
-from ...models.action_type import ActionType
-from ...services.conbus_output_service import ConbusOutputService
+from xp.api.models.api import ApiErrorResponse, ApiResponse
+from xp.api.routers.conbus import router
+from xp.api.routers.errors import handle_service_error
+from xp.models.telegram.action_type import ActionType
+from xp.services.conbus.conbus_output_service import ConbusOutputService
 
 logger = logging.getLogger(__name__)
 
@@ -26,6 +27,7 @@ logger = logging.getLogger(__name__)
     },
 )
 async def input_action(
+    request: Request,
     action: ActionType = ActionType.OFF_PRESS,
     serial: str = "1702033007",
     device_input: int = 0,
@@ -35,7 +37,7 @@ async def input_action(
 
     Sends a broadcastInput telegram and collects responses from all connected devices.
     """
-    service = ConbusOutputService()
+    service = request.app.state.container.get_container().resolve(ConbusOutputService)
 
     # SendInput telegram and receive responses
     with service:
@@ -72,6 +74,7 @@ async def input_action(
     },
 )
 async def output_status(
+    request: Request,
     serial_number: str,
 ) -> Union[ApiResponse, ApiErrorResponse, JSONResponse]:
     """
@@ -79,7 +82,7 @@ async def output_status(
 
     Sends a broadcastInput telegram and collects responses from all connected devices.
     """
-    service = ConbusOutputService()
+    service = request.app.state.container.get_container().resolve(ConbusOutputService)
 
     # SendInput telegram and receive responses
     with service:
@@ -113,6 +116,7 @@ async def output_status(
     },
 )
 async def output_state(
+    request: Request,
     serial_number: str,
 ) -> Union[ApiResponse, ApiErrorResponse, JSONResponse]:
     """
@@ -120,7 +124,7 @@ async def output_state(
 
     Sends a broadcastInput telegram and collects responses from all connected devices.
     """
-    service = ConbusOutputService()
+    service = request.app.state.container.get_container().resolve(ConbusOutputService)
 
     # SendInput telegram and receive responses
     with service:
