@@ -1,22 +1,22 @@
 """Conbus reverse proxy operations CLI commands."""
 
-import click
 import json
 import signal
 import sys
+from types import FrameType
+from typing import Any, Dict, Optional
+
+import click
+from click import Context
 from click_help_colors import HelpColorsGroup
 
-from typing import Optional, Dict, Any
-from types import FrameType
-
-from ...services.reverse_proxy_service import (
-    ReverseProxyService,
+from xp.cli.utils.decorators import handle_service_errors
+from xp.cli.utils.error_handlers import CLIErrorHandler
+from xp.cli.utils.formatters import OutputFormatter
+from xp.services.reverse_proxy_service import (
     ReverseProxyError,
+    ReverseProxyService,
 )
-from ..utils.decorators import handle_service_errors
-from ..utils.formatters import OutputFormatter
-from ..utils.error_handlers import CLIErrorHandler
-
 
 # Global proxy instance
 global_proxy_instance: Optional[ReverseProxyService] = None
@@ -41,7 +41,8 @@ def reverse_proxy() -> None:
 )
 @click.option("--config", "-c", default="rp.yml", help="Configuration file path")
 @handle_service_errors(ReverseProxyError)
-def start_proxy(port: int, config: str) -> None:
+@click.pass_context
+def start_proxy(ctx: Context, port: int, config: str) -> None:
     """
     Start the Conbus reverse proxy server.
 
@@ -67,10 +68,9 @@ def start_proxy(port: int, config: str) -> None:
             click.echo(json.dumps(error_response, indent=2))
             raise SystemExit(1)
 
-        # Create proxy instance
-        global_proxy_instance = ReverseProxyService(
-            config_path=config, listen_port=port
-        )
+        # Load configuration and create proxy instance
+        service = ctx.obj.get("container").get_container().resolve(ReverseProxyService)
+        global_proxy_instance = service
 
         # Handle graceful shutdown on SIGINT
         def signal_handler(signum: int, frame: Optional[FrameType]) -> None:
