@@ -1,7 +1,8 @@
-import click
 from typing import Any, Optional
 
-from xp.models.system_function import SystemFunction
+import click
+
+from xp.models.telegram.system_function import SystemFunction
 
 
 # noinspection DuplicatedCode
