@@ -9,12 +9,10 @@ import socket
 import threading
 import time
 from datetime import datetime
-from pathlib import Path
-from typing import Optional, Dict
+from typing import Dict, Optional
 
-import yaml
-
-from ..models.response import Response
+from xp.models import ConbusClientConfig
+from xp.models.response import Response
 
 
 class ReverseProxyError(Exception):
@@ -32,9 +30,15 @@ class ReverseProxyService:
     bidirectional traffic with timestamps.
     """
 
-    def __init__(self, config_path: str = "cli.yml", listen_port: int = 10001):
+    def __init__(
+        self,
+        cli_config: ConbusClientConfig,
+        listen_port: int,
+    ):
         """Initialize the Conbus reverse proxy service"""
-        self.config_path = config_path
+        # Set up logging first
+        self.logger = logging.getLogger(__name__)
+
         self.listen_port = listen_port
         self.server_socket: Optional[socket.socket] = None
         self.is_running = False
@@ -42,39 +46,17 @@ class ReverseProxyService:
         self.connection_counter = 0
 
         # Target server configuration
-        self.target_ip = "127.0.0.1"
-        self.target_port = 10001
-        self.target_timeout = 0.1
+        self.cli_config = cli_config
 
-        # Set up logging
-        self.logger = logging.getLogger(__name__)
+    @property
+    def target_ip(self) -> str:
+        """Get target server IP"""
+        return self.cli_config.conbus.ip
 
-        # Load configuration
-        self._load_config()
-
-    def _load_config(self) -> None:
-        """Load target server configuration from cli.yml"""
-        try:
-            if Path(self.config_path).exists():
-                with Path(self.config_path).open("r") as file:
-                    config = yaml.safe_load(file)
-                    conbus_config = config.get("conbus", {})
-
-                    self.target_ip = conbus_config.get("ip", self.target_ip)
-                    self.target_port = conbus_config.get("port", self.target_port)
-                    self.target_timeout = conbus_config.get(
-                        "timeout", self.target_timeout
-                    )
-
-                    self.logger.info(
-                        f"Loaded target server config: {self.target_ip}:{self.target_port}"
-                    )
-            else:
-                self.logger.warning(
-                    f"Config file {self.config_path} not found, using defaults"
-                )
-        except Exception as e:
-            self.logger.error(f"Error loading config file: {e}")
+    @property
+    def target_port(self) -> int:
+        """Get target server port"""
+        return self.cli_config.conbus.port
 
     def start_proxy(self) -> Response:
         """Start the reverse proxy server"""
@@ -94,11 +76,15 @@ class ReverseProxyService:
 
             self.is_running = True
             self.logger.info(f"Reverse proxy started on port {self.listen_port}")
-            self.logger.info(f"Forwarding to {self.target_ip}:{self.target_port}")
+            self.logger.info(
+                f"Forwarding to {self.cli_config.conbus.ip}:{self.cli_config.conbus.port}"
+            )
 
             # Print startup message
             print(f"Conbus Reverse Proxy started on port {self.listen_port}")
-            print(f"Forwarding telegrams to {self.target_ip}:{self.target_port}")
+            print(
+                f"Forwarding telegrams to {self.cli_config.conbus.ip}:{self.cli_config.conbus.port}"
+            )
             print("Monitoring all traffic...\n")
 
             # Start accepting connections in background thread
@@ -111,8 +97,8 @@ class ReverseProxyService:
                 success=True,
                 data={
                     "listen_port": self.listen_port,
-                    "target_ip": self.target_ip,
-                    "target_port": self.target_port,
+                    "target_ip": self.cli_config.conbus.ip,
+                    "target_port": self.cli_config.conbus.port,
                     "message": "Reverse proxy started successfully",
                 },
                 error=None,
@@ -159,8 +145,8 @@ class ReverseProxyService:
             data={
                 "running": self.is_running,
                 "listen_port": self.listen_port,
-                "target_ip": self.target_ip,
-                "target_port": self.target_port,
+                "target_ip": self.cli_config.conbus.ip,
+                "target_port": self.cli_config.conbus.port,
                 "active_connections": len(self.active_connections),
                 "connections": {
                     conn_id: {
@@ -212,8 +198,10 @@ class ReverseProxyService:
         try:
             # Connect to target server
             server_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            server_socket.settimeout(self.target_timeout)
-            server_socket.connect((self.target_ip, self.target_port))
+            server_socket.settimeout(self.cli_config.conbus.timeout)
+            server_socket.connect(
+                (self.cli_config.conbus.ip, self.cli_config.conbus.port)
+            )
 
             # Store connection info
             self.active_connections[conn_id] = {
@@ -225,7 +213,7 @@ class ReverseProxyService:
             }
 
             self.logger.info(
-                f"Connected to target server {self.target_ip}:{self.target_port} [{conn_id}]"
+                f"Connected to target server {self.cli_config.conbus.ip}:{self.cli_config.conbus.port} [{conn_id}]"
             )
 
             # Set timeouts for idle connections
