@@ -1,15 +1,16 @@
 """Integration tests for Conbus datapoint functionality."""
 
-from unittest.mock import Mock, patch
+from unittest.mock import Mock
+
 from click.testing import CliRunner
 
 from xp.cli.main import cli
-from xp.models.conbus_datapoint import ConbusDatapointResponse
-from xp.models.datapoint_type import DataPointType
-from xp.models.system_function import SystemFunction
-from xp.services.conbus_datapoint_service import (
-    ConbusDatapointService,
+from xp.models.conbus.conbus_datapoint import ConbusDatapointResponse
+from xp.models.telegram.datapoint_type import DataPointType
+from xp.models.telegram.system_function import SystemFunction
+from xp.services.conbus.conbus_datapoint_service import (
     ConbusDatapointError,
+    ConbusDatapointService,
 )
 
 
@@ -22,13 +23,11 @@ class TestConbusDatapointIntegration:
         self.valid_serial = "0123450001"
         self.invalid_serial = "invalid"
 
-    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
-    def test_conbus_datapoint_all_valid_serial(self, mock_service_class):
+    def test_conbus_datapoint_all_valid_serial(self):
         """Test querying all datapoints with valid serial number"""
 
         # Mock successful response
         mock_service = Mock()
-        mock_service_class.return_value = mock_service
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
 
@@ -47,9 +46,17 @@ class TestConbusDatapointIntegration:
         )
         mock_service.query_all_datapoints.return_value = mock_response
 
+        # Setup mock container to resolve ConbusDatapointService
+        mock_container = Mock()
+        mock_container.resolve.return_value = mock_service
+        mock_service_container = Mock()
+        mock_service_container.get_container.return_value = mock_container
+
         # Run CLI command
         result = self.runner.invoke(
-            cli, ["conbus", "datapoint", "all", self.valid_serial]
+            cli,
+            ["conbus", "datapoint", "all", self.valid_serial],
+            obj={"container": mock_service_container},
         )
 
         # Debug output
@@ -70,13 +77,11 @@ class TestConbusDatapointIntegration:
         assert '"datapoints"' in result.output
         assert '"MODULE_TYPE": "XP33LED"' in result.output
 
-    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
-    def test_conbus_datapoint_all_invalid_serial(self, mock_service_class):
+    def test_conbus_datapoint_all_invalid_serial(self):
         """Test querying all datapoints with invalid serial number"""
 
         # Mock service that raises error
         mock_service = Mock()
-        mock_service_class.return_value = mock_service
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
 
@@ -84,22 +89,28 @@ class TestConbusDatapointIntegration:
             "Invalid serial number"
         )
 
+        # Setup mock container to resolve ConbusDatapointService
+        mock_container = Mock()
+        mock_container.resolve.return_value = mock_service
+        mock_service_container = Mock()
+        mock_service_container.get_container.return_value = mock_container
+
         # Run CLI command
         result = self.runner.invoke(
-            cli, ["conbus", "datapoint", "all", self.invalid_serial]
+            cli,
+            ["conbus", "datapoint", "all", self.invalid_serial],
+            obj={"container": mock_service_container},
         )
 
         # Should handle the error gracefully
         assert result.exit_code != 0
         assert "Invalid serial number" in result.output or "Error" in result.output
 
-    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
-    def test_conbus_datapoint_connection_error(self, mock_service_class):
+    def test_conbus_datapoint_connection_error(self):
         """Test handling network connection failures"""
 
         # Mock service that raises connection error
         mock_service = Mock()
-        mock_service_class.return_value = mock_service
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
 
@@ -107,22 +118,28 @@ class TestConbusDatapointIntegration:
             "Connection failed"
         )
 
+        # Setup mock container to resolve ConbusDatapointService
+        mock_container = Mock()
+        mock_container.resolve.return_value = mock_service
+        mock_service_container = Mock()
+        mock_service_container.get_container.return_value = mock_container
+
         # Run CLI command
         result = self.runner.invoke(
-            cli, ["conbus", "datapoint", "all", self.valid_serial]
+            cli,
+            ["conbus", "datapoint", "all", self.valid_serial],
+            obj={"container": mock_service_container},
         )
 
         # Should handle the error gracefully
         assert "Connection failed" in result.output or "Error" in result.output
         assert result.exit_code != 0
 
-    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
-    def test_conbus_datapoint_invalid_response(self, mock_service_class):
+    def test_conbus_datapoint_invalid_response(self):
         """Test handling invalid responses from the server"""
 
         # Mock service with failed response
         mock_service = Mock()
-        mock_service_class.return_value = mock_service
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
 
@@ -134,9 +151,17 @@ class TestConbusDatapointIntegration:
         )
         mock_service.query_all_datapoints.return_value = mock_response
 
+        # Setup mock container to resolve ConbusDatapointService
+        mock_container = Mock()
+        mock_container.resolve.return_value = mock_service
+        mock_service_container = Mock()
+        mock_service_container.get_container.return_value = mock_container
+
         # Run CLI command
         result = self.runner.invoke(
-            cli, ["conbus", "datapoint", "all", self.valid_serial]
+            cli,
+            ["conbus", "datapoint", "all", self.valid_serial],
+            obj={"container": mock_service_container},
         )
 
         # Should return the failed response
@@ -144,13 +169,11 @@ class TestConbusDatapointIntegration:
         assert result.exit_code == 0  # CLI succeeds but response indicates failure
         assert "Invalid response from server" in result.output
 
-    @patch("xp.cli.commands.conbus_datapoint_commands.ConbusDatapointService")
-    def test_conbus_datapoint_empty_datapoints(self, mock_service_class):
+    def test_conbus_datapoint_empty_datapoints(self):
         """Test handling when no datapoints are returned"""
 
         # Mock service with successful but empty response
         mock_service = Mock()
-        mock_service_class.return_value = mock_service
         mock_service.__enter__ = Mock(return_value=mock_service)
         mock_service.__exit__ = Mock(return_value=None)
 
@@ -162,9 +185,17 @@ class TestConbusDatapointIntegration:
         )
         mock_service.query_all_datapoints.return_value = mock_response
 
+        # Setup mock container to resolve ConbusDatapointService
+        mock_container = Mock()
+        mock_container.resolve.return_value = mock_service
+        mock_service_container = Mock()
+        mock_service_container.get_container.return_value = mock_container
+
         # Run CLI command
         result = self.runner.invoke(
-            cli, ["conbus", "datapoint", "all", self.valid_serial]
+            cli,
+            ["conbus", "datapoint", "all", self.valid_serial],
+            obj={"container": mock_service_container},
         )
 
         # Should succeed with empty datapoints
@@ -182,18 +213,12 @@ class TestConbusDatapointService:
         """Set up test fixtures"""
         self.valid_serial = "0123450001"
 
-    @patch("xp.services.conbus_datapoint_service.ConbusService")
-    @patch("xp.services.conbus_datapoint_service.TelegramService")
-    def test_query_all_datapoints_success(
-        self, mock_telegram_service, mock_conbus_service
-    ):
+    def test_query_all_datapoints_success(self):
         """Test successful querying of all datapoints"""
 
         # Mock dependencies
-        mock_conbus = Mock()
-        mock_conbus_service.return_value = mock_conbus
-        mock_telegram = Mock()
-        mock_telegram_service.return_value = mock_telegram
+        mock_telegram_service = Mock()
+        mock_conbus_service = Mock()
 
         # Mock successful telegram response for each datapoint type
         mock_reply_telegram = Mock()
@@ -203,7 +228,9 @@ class TestConbusDatapointService:
         mock_single_response.success = True
         mock_single_response.datapoint_telegram = mock_reply_telegram
 
-        service = ConbusDatapointService()
+        service = ConbusDatapointService(
+            telegram_service=mock_telegram_service, conbus_service=mock_conbus_service
+        )
 
         # Mock the send_telegram method to return successful responses
         service.query_datapoint = Mock(return_value=mock_single_response)
@@ -224,7 +251,13 @@ class TestConbusDatapointService:
     def test_query_all_datapoints_partial_failure(self):
         """Test querying datapoints when some datapoints fail"""
 
-        service = ConbusDatapointService()
+        # Mock dependencies
+        mock_telegram_service = Mock()
+        mock_conbus_service = Mock()
+
+        service = ConbusDatapointService(
+            telegram_service=mock_telegram_service, conbus_service=mock_conbus_service
+        )
 
         # Mock send_telegram to return success for some, failure for others
         def mock_send_telegram(datapoint_type, _serial_number):
