@@ -2,9 +2,15 @@
 
 import pytest
 
-from xp.models.action_type import ActionType
-from xp.services.conbus_datapoint_service import ConbusDatapointService
-from xp.services.telegram_output_service import TelegramOutputService, XPOutputError
+from xp.models import ConbusClientConfig
+from xp.models.telegram.action_type import ActionType
+from xp.services.conbus.conbus_datapoint_service import ConbusDatapointService
+from xp.services.conbus.conbus_service import ConbusService
+from xp.services.telegram.telegram_output_service import (
+    TelegramOutputService,
+    XPOutputError,
+)
+from xp.services.telegram.telegram_service import TelegramService
 
 
 class TestOutputIntegration:
@@ -12,8 +18,13 @@ class TestOutputIntegration:
 
     def setup_method(self):
         """Set up test fixtures."""
-        self.output_service = TelegramOutputService()
-        self.conbus_service = ConbusDatapointService()
+        cli_config = ConbusClientConfig.from_yaml("cli.yml")
+        conbus_service = ConbusService(cli_config)
+        telegram_service = TelegramService()
+        self.output_service = TelegramOutputService(telegram_service=telegram_service)
+        self.conbus_service = ConbusDatapointService(
+            telegram_service=telegram_service, conbus_service=conbus_service
+        )
 
     def test_end_to_end_action_generation_and_parsing(self):
         """Test complete flow: generate telegram, parse it back."""
@@ -48,7 +59,7 @@ class TestOutputIntegration:
         mock_response = "<R0012345008F02D12xxxx1010FJ>"
         status = self.output_service.parse_status_response(mock_response)
 
-        expected = {0: False, 1: True, 2: False, 3: True}
+        expected = [False, True, False, True]
         assert status == expected
 
     def test_all_output_combinations(self):
@@ -100,7 +111,7 @@ class TestOutputIntegration:
 
     def test_telegram_service_integration(self):
         """Test integration with existing telegram service."""
-        from xp.services.telegram_service import TelegramService
+        from xp.services.telegram.telegram_service import TelegramService
 
         telegram_service = TelegramService()
 
@@ -113,7 +124,7 @@ class TestOutputIntegration:
         parsed_generic = telegram_service.parse_telegram(xp24_telegram)
 
         # Should be parsed as SystemTelegram
-        from xp.models.system_telegram import SystemTelegram
+        from xp.models.telegram.system_telegram import SystemTelegram
 
         assert isinstance(parsed_generic, SystemTelegram)
         assert parsed_generic.serial_number == "0012345008"
