@@ -4,11 +4,13 @@ Tests the reply telegram model functionality including parsing,
 value interpretation, and data structure integrity.
 """
 
-import pytest
 from datetime import datetime
-from xp.models.reply_telegram import ReplyTelegram
-from xp.models.datapoint_type import DataPointType
-from xp.models.system_function import SystemFunction
+
+import pytest
+
+from xp.models.telegram.datapoint_type import DataPointType
+from xp.models.telegram.reply_telegram import ReplyTelegram
+from xp.models.telegram.system_function import SystemFunction
 
 
 class TestReplyTelegram:
