@@ -1,34 +1,26 @@
 import socket
 from datetime import datetime
-from unittest.mock import Mock, patch, MagicMock
+from unittest.mock import MagicMock, Mock, patch
 
 import pytest
 
-from xp.services.conbus_datapoint_service import (
-    ConbusService,
-)
+from xp.models.conbus.conbus_client_config import ClientConfig, ConbusClientConfig
+from xp.services.conbus.conbus_service import ConbusService
 
 
 class TestConbusService:
     """Test cases for ConbusService"""
 
     @pytest.fixture
-    def mock_config_file(self, tmp_path):
-        """Create a temporary config file for testing"""
-        config_file = tmp_path / "test_cli.yml"
-        config_content = """
-conbus:
-  ip: 10.0.0.1
-  port: 8080
-  timeout: 15
-"""
-        config_file.write_text(config_content)
-        return str(config_file)
+    def mock_config(self):
+        """Create a test config"""
+        client_config = ClientConfig(ip="10.0.0.1", port=8080, timeout=15)
+        return ConbusClientConfig(conbus=client_config)
 
     @pytest.fixture
-    def service(self, mock_config_file):
+    def service(self, mock_config):
         """Create service instance with test config"""
-        return ConbusService(config_path=mock_config_file)
+        return ConbusService(client_config=mock_config)
 
     @pytest.fixture
     def mock_socket(self):
@@ -46,30 +38,32 @@ conbus:
 class TestServiceInitialization(TestConbusService):
     """Test service initialization and configuration loading"""
 
-    def test_default_initialization(self, tmp_path):
+    def test_default_initialization(self):
         """Test service initialization with default config"""
-        # Use a non-existent config file to test defaults
-        non_existent_config = str(tmp_path / "non_existent.yml")
-        service = ConbusService(config_path=non_existent_config)
+        # Create service with default config
+        default_config = ConbusClientConfig()
+        service = ConbusService(client_config=default_config)
 
-        assert service.config.ip == "192.168.1.100"
-        assert service.config.port == 10001
-        assert service.config.timeout == 0.1
+        assert service.client_config.conbus.ip == "192.168.1.100"
+        assert service.client_config.conbus.port == 10001
+        assert service.client_config.conbus.timeout == 0.1
 
-    def test_nonexistent_config_file(self):
-        """Test handling of non-existent config file"""
-        service = ConbusService(config_path="nonexistent.yml")
+    def test_custom_config(self):
+        """Test service initialization with custom config"""
+        # Create service with custom config
+        custom_client_config = ClientConfig(ip="10.1.1.1", port=9999, timeout=5.0)
+        custom_config = ConbusClientConfig(conbus=custom_client_config)
+        service = ConbusService(client_config=custom_config)
 
-        # Should use defaults when config file doesn't exist
-        assert service.config.ip == "192.168.1.100"
-        assert service.config.port == 10001
-        assert service.config.timeout == 0.1
+        assert service.client_config.conbus.ip == "10.1.1.1"
+        assert service.client_config.conbus.port == 9999
+        assert service.client_config.conbus.timeout == 5.0
 
 
 class TestConnectionManagement(TestConbusService):
     """Test connection establishment and management"""
 
-    @patch("xp.services.conbus_connection_pool.ConbusConnectionPool")
+    @patch("xp.services.conbus.conbus_connection_pool.ConbusConnectionPool")
     def test_successful_connection(self, mock_pool_class, service):
         """Test successful connection establishment"""
         mock_pool_instance = MagicMock()
@@ -88,7 +82,7 @@ class TestConnectionManagement(TestConbusService):
         mock_pool_instance.__enter__.assert_called_once()
         mock_pool_instance.__exit__.assert_called_once()
 
-    @patch("xp.services.conbus_connection_pool.ConbusConnectionPool")
+    @patch("xp.services.conbus.conbus_connection_pool.ConbusConnectionPool")
     def test_connection_timeout(self, mock_pool_class, service):
         """Test connection timeout handling"""
         mock_pool_instance = MagicMock()
@@ -104,7 +98,7 @@ class TestConnectionManagement(TestConbusService):
         assert "Failed to establish connection pool" in result.error
         assert service.is_connected is False
 
-    @patch("xp.services.conbus_connection_pool.ConbusConnectionPool")
+    @patch("xp.services.conbus.conbus_connection_pool.ConbusConnectionPool")
     def test_connection_error(self, mock_pool_class, service):
         """Test connection error handling"""
         mock_pool_instance = MagicMock()
@@ -122,7 +116,7 @@ class TestConnectionManagement(TestConbusService):
         assert "Failed to establish connection pool to " in result.error
         assert service.is_connected is False
 
-    @patch("xp.services.conbus_connection_pool.ConbusConnectionPool")
+    @patch("xp.services.conbus.conbus_connection_pool.ConbusConnectionPool")
     def test_already_connected(self, mock_pool_class, service):
         """Test connecting - pool will handle repeated connections gracefully"""
         mock_pool_instance = MagicMock()
@@ -139,7 +133,7 @@ class TestConnectionManagement(TestConbusService):
         assert result.success is True
         assert "Connection pool ready for " in result.data["message"]
 
-    @patch("xp.services.conbus_connection_pool.ConbusConnectionPool")
+    @patch("xp.services.conbus.conbus_connection_pool.ConbusConnectionPool")
     def test_disconnect(self, mock_pool_class, service):
         """Test disconnection"""
         mock_pool_instance = MagicMock()
@@ -154,7 +148,7 @@ class TestConnectionManagement(TestConbusService):
         assert service.is_connected is False
         mock_pool_instance.close.assert_called_once()
 
-    @patch("xp.services.conbus_connection_pool.ConbusConnectionPool")
+    @patch("xp.services.conbus.conbus_connection_pool.ConbusConnectionPool")
     def test_disconnect_with_error(self, mock_pool_class, service):
         """Test disconnection with connection pool error"""
         mock_pool_instance = MagicMock()
@@ -194,7 +188,7 @@ class TestConnectionStatus(TestConbusService):
 class TestContextManager(TestConbusService):
     """Test context manager functionality"""
 
-    @patch("xp.services.conbus_connection_pool.ConbusConnectionPool")
+    @patch("xp.services.conbus.conbus_connection_pool.ConbusConnectionPool")
     def test_context_manager_enter_exit(self, mock_pool_class, service):
         """Test context manager enter and exit"""
         mock_pool_instance = MagicMock()
@@ -215,7 +209,7 @@ class TestContextManager(TestConbusService):
 class TestErrorHandling(TestConbusService):
     """Test error handling scenarios"""
 
-    @patch("xp.services.conbus_service.ConbusConnectionPool")
+    @patch("xp.services.conbus.conbus_service.ConbusConnectionPool")
     def test_response_receiving_error(self, mock_pool_class, service, mock_socket):
         """Test error handling during response receiving"""
         mock_pool_instance = MagicMock()
