@@ -1,9 +1,12 @@
 """Tests for ServerService."""
 
 from unittest.mock import Mock, patch
+
 import pytest
 
-from xp.services.server_service import ServerService, ServerError
+from xp.services.server.server_service import ServerError, ServerService
+from xp.services.telegram.telegram_discover_service import TelegramDiscoverService
+from xp.services.telegram.telegram_service import TelegramService
 
 
 class TestServerError:
@@ -29,12 +32,14 @@ class TestServerError:
 class TestServerServiceInit:
     """Test ServerService initialization."""
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_init_with_defaults(self, mock_path):
         """Test initialization with default parameters."""
         mock_path.return_value.exists.return_value = False
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert service.config_path == "server.yml"
         assert service.port == 10001
@@ -43,18 +48,22 @@ class TestServerServiceInit:
         assert service.devices == []
         assert service.device_services == {}
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_init_with_custom_params(self, mock_path):
         """Test initialization with custom parameters."""
         mock_path.return_value.exists.return_value = False
 
-        service = ServerService(config_path="custom.yml", port=8080)
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(
+            telegram_service, discover_service, config_path="custom.yml", port=8080
+        )
 
         assert service.config_path == "custom.yml"
         assert service.port == 8080
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_init_loads_config_when_exists(self, mock_config, mock_path):
         """Test initialization loads config when file exists."""
         mock_path.return_value.exists.return_value = True
@@ -64,7 +73,9 @@ class TestServerServiceInit:
         mock_module.module_type = "XP33"
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert len(service.devices) == 1
         mock_config.from_yaml.assert_called_once_with("server.yml")
@@ -73,18 +84,20 @@ class TestServerServiceInit:
 class TestServerServiceConfig:
     """Test ServerService configuration methods."""
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_load_device_config_file_not_found(self, mock_path):
         """Test loading config when file doesn't exist."""
         mock_path.return_value.exists.return_value = False
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert service.devices == []
         assert service.device_services == {}
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_load_device_config_with_disabled_devices(self, mock_config, mock_path):
         """Test loading config filters out disabled devices."""
         mock_path.return_value.exists.return_value = True
@@ -92,68 +105,80 @@ class TestServerServiceConfig:
         mock_disabled = Mock(enabled=False, serial_number="22222", module_type="XP33")
         mock_config.from_yaml.return_value = Mock(root=[mock_enabled, mock_disabled])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert len(service.devices) == 1
         assert service.devices[0].serial_number == "11111"
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_load_device_config_handles_exception(self, mock_config, mock_path):
         """Test loading config handles exceptions gracefully."""
         mock_path.return_value.exists.return_value = True
         mock_config.from_yaml.side_effect = Exception("Parse error")
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert service.devices == []
         assert service.device_services == {}
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_create_device_services_xp33(self, mock_config, mock_path):
         """Test creating XP33 device service."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="12345", module_type="XP33")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert "12345" in service.device_services
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_create_device_services_cp20(self, mock_config, mock_path):
         """Test creating CP20 device service."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="11111", module_type="CP20")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert "11111" in service.device_services
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_create_device_services_xp20(self, mock_config, mock_path):
         """Test creating XP20 device service."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="22222", module_type="XP20")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert "22222" in service.device_services
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_create_device_services_unknown_type(self, mock_config, mock_path):
         """Test creating device service with unknown type."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="99999", module_type="UNKNOWN")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert "99999" not in service.device_services
 
@@ -161,30 +186,36 @@ class TestServerServiceConfig:
 class TestServerServiceLifecycle:
     """Test ServerService start/stop methods."""
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_start_server_when_already_running(self, mock_path):
         """Test starting server when already running raises error."""
         mock_path.return_value.exists.return_value = False
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         service.is_running = True
 
         with pytest.raises(ServerError, match="already running"):
             service.start_server()
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_stop_server_when_not_running(self, mock_path):
         """Test stopping server when not running does nothing."""
         mock_path.return_value.exists.return_value = False
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         service.is_running = False
 
         service.stop_server()  # Should not raise
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_stop_server_closes_socket(self, mock_path):
         """Test stopping server closes socket."""
         mock_path.return_value.exists.return_value = False
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         service.is_running = True
         service.server_socket = Mock()
 
@@ -193,11 +224,13 @@ class TestServerServiceLifecycle:
         service.server_socket.close.assert_called_once()
         assert service.is_running is False
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_stop_server_handles_close_exception(self, mock_path):
         """Test stopping server handles socket close exceptions."""
         mock_path.return_value.exists.return_value = False
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         service.is_running = True
         service.server_socket = Mock()
         service.server_socket.close.side_effect = Exception("Close failed")
@@ -210,15 +243,17 @@ class TestServerServiceLifecycle:
 class TestServerServiceStatus:
     """Test ServerService status methods."""
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_get_server_status(self, mock_config, mock_path):
         """Test getting server status."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="12345", module_type="XP33")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService(port=8080)
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service, port=8080)
         service.is_running = True
 
         status = service.get_server_status()
@@ -228,11 +263,13 @@ class TestServerServiceStatus:
         assert status["devices_configured"] == 1
         assert "12345" in status["device_list"]
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_get_server_status_not_running(self, mock_path):
         """Test getting server status when not running."""
         mock_path.return_value.exists.return_value = False
-        status = ServerService().get_server_status()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        status = ServerService(telegram_service, discover_service).get_server_status()
 
         assert status["running"] is False
         assert status["devices_configured"] == 0
@@ -242,11 +279,13 @@ class TestServerServiceStatus:
 class TestServerServiceRequestProcessing:
     """Test ServerService request processing."""
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_process_request_invalid_telegram(self, mock_path):
         """Test processing invalid telegram returns empty list."""
         mock_path.return_value.exists.return_value = False
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         service.telegram_service = Mock()
         service.telegram_service.parse_system_telegram.return_value = None
 
@@ -254,15 +293,17 @@ class TestServerServiceRequestProcessing:
 
         assert responses == []
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_process_request_discover(self, mock_config, mock_path):
         """Test processing discover request."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="12345", module_type="XP33")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         mock_telegram = Mock()
         service.telegram_service.parse_system_telegram = Mock(
             return_value=mock_telegram
@@ -277,15 +318,17 @@ class TestServerServiceRequestProcessing:
         assert len(responses) == 1
         assert "<DISCOVER_RESPONSE>" in responses[0]
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_process_request_specific_device(self, mock_config, mock_path):
         """Test processing request for specific device."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="12345", module_type="XP33")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         mock_telegram = Mock(serial_number="12345")
         service.telegram_service.parse_system_telegram = Mock(
             return_value=mock_telegram
@@ -300,8 +343,8 @@ class TestServerServiceRequestProcessing:
         assert len(responses) == 1
         assert "<RESPONSE>" in responses[0]
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_process_request_broadcast(self, mock_config, mock_path):
         """Test processing broadcast request."""
         mock_path.return_value.exists.return_value = True
@@ -309,7 +352,9 @@ class TestServerServiceRequestProcessing:
         mock_module2 = Mock(enabled=True, serial_number="22222", module_type="XP20")
         mock_config.from_yaml.return_value = Mock(root=[mock_module1, mock_module2])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         mock_telegram = Mock(serial_number="0000000000")
         service.telegram_service.parse_system_telegram = Mock(
             return_value=mock_telegram
@@ -326,8 +371,8 @@ class TestServerServiceRequestProcessing:
 
         assert len(responses) == 2
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_process_request_broadcast_with_none_response(self, mock_config, mock_path):
         """Test processing broadcast request where some devices return None."""
         mock_path.return_value.exists.return_value = True
@@ -335,7 +380,9 @@ class TestServerServiceRequestProcessing:
         mock_module2 = Mock(enabled=True, serial_number="22222", module_type="XP20")
         mock_config.from_yaml.return_value = Mock(root=[mock_module1, mock_module2])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         mock_telegram = Mock(serial_number="0000000000")
         service.telegram_service.parse_system_telegram = Mock(
             return_value=mock_telegram
@@ -353,11 +400,13 @@ class TestServerServiceRequestProcessing:
         assert len(responses) == 1  # Only one response
         assert "<RESPONSE1>" in responses[0]
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_process_request_device_not_found(self, mock_path):
         """Test processing request for non-existent device."""
         mock_path.return_value.exists.return_value = False
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         mock_telegram = Mock(serial_number="99999")
         service.telegram_service.parse_system_telegram = Mock(
             return_value=mock_telegram
@@ -368,11 +417,13 @@ class TestServerServiceRequestProcessing:
 
         assert responses == []
 
-    @patch("xp.services.server_service.Path")
+    @patch("xp.services.server.server_service.Path")
     def test_process_request_handles_exception(self, mock_path):
         """Test processing request handles exceptions."""
         mock_path.return_value.exists.return_value = False
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
         mock_telegram_service = Mock()
         mock_telegram_service.parse_system_telegram.side_effect = Exception(
             "Parse error"
@@ -387,15 +438,17 @@ class TestServerServiceRequestProcessing:
 class TestServerServiceReload:
     """Test ServerService config reload."""
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_reload_config(self, mock_config, mock_path):
         """Test reloading configuration."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="12345", module_type="XP33")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         # Change config
         mock_module2 = Mock(enabled=True, serial_number="22222", module_type="XP20")
@@ -409,50 +462,58 @@ class TestServerServiceReload:
 class TestServerServiceDeviceTypes:
     """Test device type creation."""
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_create_xp24_service(self, mock_config, mock_path):
         """Test creating XP24 device service."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="24242", module_type="XP24")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert "24242" in service.device_services
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_create_xp33led_service(self, mock_config, mock_path):
         """Test creating XP33LED device service."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="33333", module_type="XP33LED")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert "33333" in service.device_services
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_create_xp130_service(self, mock_config, mock_path):
         """Test creating XP130 device service."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="13013", module_type="XP130")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert "13013" in service.device_services
 
-    @patch("xp.services.server_service.Path")
-    @patch("xp.services.server_service.ConsonModuleListConfig")
+    @patch("xp.services.server.server_service.Path")
+    @patch("xp.services.server.server_service.ConsonModuleListConfig")
     def test_create_xp230_service(self, mock_config, mock_path):
         """Test creating XP230 device service."""
         mock_path.return_value.exists.return_value = True
         mock_module = Mock(enabled=True, serial_number="23023", module_type="XP230")
         mock_config.from_yaml.return_value = Mock(root=[mock_module])
 
-        service = ServerService()
+        telegram_service = TelegramService()
+        discover_service = TelegramDiscoverService()
+        service = ServerService(telegram_service, discover_service)
 
         assert "23023" in service.device_services
